@@ -1,11 +1,9 @@
-/* eslint-disable no-unused-vars */
-
 import * as React from 'react';
+import { ChartDonut } from '@patternfly/react-charts';
 import { shallow, ShallowWrapper } from 'enzyme';
 
 import { SpecCapability, Descriptor } from '../../../../../public/components/operator-lifecycle-manager/descriptors/types';
 import { PodStatusChart, PodStatusChartProps } from '../../../../../public/components/operator-lifecycle-manager/descriptors/status/pods';
-import { Donut } from '../../../../../public/components/graphs';
 
 describe(PodStatusChart.displayName, () => {
   let wrapper: ShallowWrapper<PodStatusChartProps>;
@@ -18,25 +16,23 @@ describe(PodStatusChart.displayName, () => {
       'description': 'The desired number of member Pods for the etcd cluster.',
       'x-descriptors': [SpecCapability.podCount],
     };
-    wrapper = shallow(<PodStatusChart statusDescriptor={descriptor} fetcher={() => null} />);
+    wrapper = shallow(<PodStatusChart statusDescriptor={descriptor} statuses={{}} />);
   });
 
   it('renders a donut chart component with correct props', () => {
-    expect(wrapper.find(Donut).props().kind).toEqual(descriptor.path);
-    expect(wrapper.find(Donut).props().title).toEqual(descriptor.displayName);
+    expect(wrapper.find(ChartDonut).props().subTitle).toEqual(descriptor.path);
+    expect(wrapper.find(ChartDonut).props().title).toEqual('0');
   });
 
-  it('passes `fetch` function to donut chart which returns a promise which resolves to chart data', (done) => {
-    const fetcher = () => ({
+  it('passes data to donut chart', () => {
+    const statuses = {
       ready: ['pod-0', 'pod-1'],
       starting: ['pod-2'],
-    });
-    wrapper = wrapper.setProps({fetcher});
-
-    wrapper.find(Donut).props().fetch().then(([values, labels]) => {
-      expect(values).toEqual([2, 1]);
-      expect(labels).toEqual(['ready', 'starting']);
-      done();
-    });
+    };
+    wrapper = wrapper.setProps({statuses});
+    expect(wrapper.find(ChartDonut).props().data).toEqual([
+      { label: '2 ready', x: 'ready', y: 2 },
+      { label: '1 starting', x: 'starting', y: 1 },
+    ]);
   });
 });
