@@ -18,12 +18,12 @@ describe('Filtering', () => {
     await crudView.isLoaded();
     await crudView.createYAMLButton.click();
     await yamlView.isLoaded();
-    const content = await yamlView.editorContent.getText();
+    const content = await yamlView.getEditorContent();
     const newContent = _.defaultsDeep({}, {metadata: {name: WORKLOAD_NAME, labels: {['lbl-filter']: testName}}}, safeLoad(content));
-    await yamlView.setContent(safeDump(newContent));
+    await yamlView.setEditorContent(safeDump(newContent));
     await crudView.saveChangesBtn.click();
     // Wait until the resource is created and the details page loads before continuing.
-    await browser.wait(until.presenceOf(crudView.actionsDropdown));
+    await browser.wait(until.presenceOf(crudView.actionsButton));
   });
 
   afterEach(() => {
@@ -36,7 +36,7 @@ describe('Filtering', () => {
     await crudView.isLoaded();
     await crudView.nameFilter.sendKeys(WORKLOAD_NAME);
     await browser.wait(until.elementToBeClickable(crudView.resourceRowNamesAndNs.first()), BROWSER_TIMEOUT);
-    await crudView.deleteRow('deployment')(WORKLOAD_NAME);
+    await crudView.deleteRow('Deployment')(WORKLOAD_NAME);
   });
 
   it('filters Pod from object detail', async() => {
@@ -75,7 +75,7 @@ describe('Filtering', () => {
     expect(crudView.resourceRowNamesAndNs.first().getText()).toContain(WORKLOAD_NAME);
   });
 
-  it('searches for object by label', async() => {
+  xit('CONSOLE-1503 - searches for object by label', async() => {
     await browser.get(`${appHost}/search/ns/${testName}`);
     await browser.wait(until.elementToBeClickable(searchView.dropdown), BROWSER_TIMEOUT);
     await searchView.selectSearchType('Deployment');
