@@ -1,5 +1,3 @@
-/* eslint-disable no-undef, no-unused-vars */
-
 import {browser, $, ExpectedConditions as until, by} from 'protractor';
 
 import { appHost, checkLogs, checkErrors, testName } from '../../protractor.conf';
@@ -19,7 +17,7 @@ describe('Test for Cluster Service Broker', () => {
   });
 
   it('displays `MariaDB` service class for `template-service-broker`', async() => {
-    await sidenavView.clickNavLink(['Catalog', 'Broker Management']);
+    await sidenavView.clickNavLink(['Service Catalog', 'Broker Management']);
     await crudView.isLoaded();
 
     await crudView.rowForName('template-service-broker').element(by.linkText('template-service-broker')).click();
