@@ -1,37 +1,42 @@
 import * as React from 'react';
 import * as _ from 'lodash-es';
 
-// eslint-disable-next-line no-unused-vars
-import { k8sCreate, K8sResourceKindReference } from '../module/k8s';
+import { Status, PodRingController, PodRing } from '@console/shared';
+import { k8sCreate, K8sKind, K8sResourceKind, K8sResourceKindReference } from '../module/k8s';
 import { errorModal } from './modals';
 import { DeploymentConfigModel } from '../models';
 import { Conditions } from './conditions';
 import { ResourceEventStream } from './events';
-import { MountedVolumes } from './mounted-vol';
+import { VolumesTable } from './volumes-table';
 import {
   DetailsPage,
-  List,
   ListPage,
-  WorkloadListHeader,
-  WorkloadListRow,
+  Table,
 } from './factory';
 import {
   AsyncComponent,
+  history,
   Kebab,
+  KebabAction,
   ContainerTable,
-  DeploymentPodCounts,
   navFactory,
   pluralize,
   ResourceSummary,
+  resourcePath,
   SectionHeading,
   togglePaused,
   WorkloadPausedAlert,
-  StatusIcon,
+  LoadingInline, getExtensionsKebabActionsForKind,
 } from './utils';
 
+import {
+  WorkloadTableRow,
+  WorkloadTableHeader,
+} from './workload-table';
+
 const DeploymentConfigsReference: K8sResourceKindReference = 'DeploymentConfig';
 
-const rollout = dc => {
+const rollout = (dc: K8sResourceKind): Promise<K8sResourceKind> => {
   const req = {
     kind: 'DeploymentRequest',
     apiVersion: 'apps.openshift.io/v1',
@@ -47,27 +52,48 @@ const rollout = dc => {
   return k8sCreate(DeploymentConfigModel, req, opts);
 };
 
-const rolloutAction = (kind, obj) => ({
+const determineReplicationControllerName = (dc: K8sResourceKind): string => {
+  return `${dc.metadata.name}-${dc.status.latestVersion}`;
+};
+
+const RolloutAction: KebabAction = (kind: K8sKind, obj: K8sResourceKind) => ({
   label: 'Start Rollout',
-  callback: () => rollout(obj).catch(err => {
+  callback: () => rollout(obj).then(deployment => {
+    history.push(resourcePath('ReplicationController', determineReplicationControllerName(deployment), deployment.metadata.namespace));
+  }).catch(err => {
     const error = err.message;
     errorModal({error});
   }),
+  accessReview: {
+    group: kind.apiGroup,
+    resource: kind.plural,
+    subresource: 'instantiate',
+    name: obj.metadata.name,
+    namespace: obj.metadata.namespace,
+    verb: 'create',
+  },
 });
 
-export const pauseAction = (kind, obj) => ({
+const PauseAction: KebabAction = (kind: K8sKind, obj: K8sResourceKind) => ({
   label: obj.spec.paused ? 'Resume Rollouts' : 'Pause Rollouts',
   callback: () => togglePaused(kind, obj).catch((err) => errorModal({error: err.message})),
+  accessReview: {
+    group: kind.apiGroup,
+    resource: kind.plural,
+    name: obj.metadata.name,
+    namespace: obj.metadata.namespace,
+    verb: 'patch',
+  },
 });
 
-const {ModifyCount, AddStorage, EditEnvironment, common} = Kebab.factory;
+const {ModifyCount, AddStorage, common} = Kebab.factory;
 
-export const menuActions = [
-  rolloutAction,
-  pauseAction,
+export const menuActions: KebabAction[] = [
+  RolloutAction,
+  PauseAction,
   ModifyCount,
   AddStorage,
-  EditEnvironment,
+  ...getExtensionsKebabActionsForKind(DeploymentConfigModel),
   ...common,
 ];
 
@@ -102,18 +128,31 @@ export const DeploymentConfigDetailsList = ({dc}) => {
   </dl>;
 };
 
-export const DeploymentConfigsDetails: React.SFC<{obj: any}> = ({obj: dc}) => {
+export const DeploymentConfigsDetails: React.FC<{obj: K8sResourceKind}> = ({obj: dc}) => {
   return <React.Fragment>
     <div className="co-m-pane__body">
       <SectionHeading text="Deployment Config Overview" />
       {dc.spec.paused && <WorkloadPausedAlert obj={dc} model={DeploymentConfigModel} />}
-      <DeploymentPodCounts resource={dc} resourceKind={DeploymentConfigModel} />
+      <PodRingController
+        namespace={dc.metadata.namespace}
+        kind={dc.kind}
+        render={(d) => {
+          return d.loaded ? <PodRing pods={d.data[dc.metadata.uid].pods}
+            obj={dc}
+            resourceKind={DeploymentConfigModel}
+            path="/spec/replicas" /> : <LoadingInline />;
+        }}
+      />
       <div className="co-m-pane__body-group">
         <div className="row">
           <div className="col-sm-6">
             <ResourceSummary resource={dc} showPodSelector showNodeSelector showTolerations>
               <dt>Status</dt>
-              <dd>{dc.status.availableReplicas === dc.status.updatedReplicas ? <StatusIcon status="Active" /> : <StatusIcon status="Updating" />}</dd>
+              <dd>
+                {dc.status.availableReplicas === dc.status.updatedReplicas && dc.spec.replicas === dc.status.availableReplicas
+                  ? <Status status="Up to date" />
+                  : <Status status="Updating" />}
+              </dd>
             </ResourceSummary>
           </div>
           <div className="col-sm-6">
@@ -127,7 +166,7 @@ export const DeploymentConfigsDetails: React.SFC<{obj: any}> = ({obj: dc}) => {
       <ContainerTable containers={dc.spec.template.spec.containers} />
     </div>
     <div className="co-m-pane__body">
-      <MountedVolumes podTemplate={dc.spec.template} heading="Mounted Volumes" />
+      <VolumesTable resource={dc} heading="Volumes" />
     </div>
     <div className="co-m-pane__body">
       <SectionHeading text="Conditions" />
@@ -154,44 +193,42 @@ const pages = [
   navFactory.events(ResourceEventStream),
 ];
 
-export const DeploymentConfigsDetailsPage: React.SFC<DeploymentConfigsDetailsPageProps> = props => {
+export const DeploymentConfigsDetailsPage: React.FC<DeploymentConfigsDetailsPageProps> = props => {
   return <DetailsPage {...props} kind={DeploymentConfigsReference} menuActions={menuActions} pages={pages} />;
 };
 DeploymentConfigsDetailsPage.displayName = 'DeploymentConfigsDetailsPage';
 
-const DeploymentConfigsRow: React.SFC<DeploymentConfigsRowProps> = props => {
-  return <WorkloadListRow {...props} kind="DeploymentConfig" actions={menuActions} />;
+const kind = 'DeploymentConfig';
+
+const DeploymentConfigTableRow: React.FC<DeploymentConfigTableRowProps> = ({obj, index, key, style}) => {
+  return (
+    <WorkloadTableRow obj={obj} index={index} key={key} style={style} menuActions={menuActions} kind={kind} />
+  );
 };
-export const DeploymentConfigsList: React.SFC = props => <List {...props} Header={WorkloadListHeader} Row={DeploymentConfigsRow} />;
+DeploymentConfigTableRow.displayName = 'DeploymentTableRow';
+type DeploymentConfigTableRowProps = {
+  obj: K8sResourceKind;
+  index: number;
+  key?: string;
+  style: object;
+};
+
+const DeploymentConfigTableHeader = () => {
+  return WorkloadTableHeader();
+};
+DeploymentConfigTableHeader.displayName = 'DeploymentConfigTableHeader';
+
+export const DeploymentConfigsList: React.FC = props => <Table {...props} aria-label="Deployment Configs" Header={DeploymentConfigTableHeader} Row={DeploymentConfigTableRow} virtualize />;
 DeploymentConfigsList.displayName = 'DeploymentConfigsList';
 
-export const DeploymentConfigsPage: React.SFC<DeploymentConfigsPageProps> = props => {
-  const createItems = {
-    image: 'From Image',
-    yaml: 'From YAML',
-  };
-
-  const createProps = {
-    items: createItems,
-    createLink: type => type === 'image'
-      ? `/deploy-image${props.namespace ? `?preselected-ns=${props.namespace}` : ''}`
-      : `/k8s/ns/${props.namespace || 'default'}/deploymentconfigs/~new`,
-  };
-  return <ListPage {...props} title="Deployment Configs" kind={DeploymentConfigsReference} ListComponent={DeploymentConfigsList} canCreate={true} createButtonText="Create" createProps={createProps} filterLabel={props.filterLabel} />;
-};
+export const DeploymentConfigsPage: React.FC<DeploymentConfigsPageProps> = props => <ListPage kind={DeploymentConfigsReference} ListComponent={DeploymentConfigsList} canCreate={true} {...props} />;
 DeploymentConfigsPage.displayName = 'DeploymentConfigsListPage';
 
-/* eslint-disable no-undef */
-export type DeploymentConfigsRowProps = {
-  obj: any,
+type DeploymentConfigsPageProps = {
+  filterLabel: string;
+  namespace: string;
 };
 
-export type DeploymentConfigsPageProps = {
-  filterLabel: string,
-  namespace: string,
+type DeploymentConfigsDetailsPageProps = {
+  match: any;
 };
-
-export type DeploymentConfigsDetailsPageProps = {
-  match: any,
-};
-/* eslint-enable no-undef */
