@@ -4,8 +4,10 @@ import * as PropTypes from 'prop-types';
 import * as React from 'react';
 import { connect } from 'react-redux';
 import { Link } from 'react-router-dom';
+import { Button } from '@patternfly/react-core';
 
-import k8sActions from '../../module/k8s/k8s-actions';
+import { KEYBOARD_SHORTCUTS } from '../../const';
+import { filterList } from '../../actions/k8s';
 import { CheckBoxes, storagePrefix } from '../row-filter';
 import { ErrorPage404, ErrorBoundaryFallback } from '../error';
 import { referenceForModel } from '../../module/k8s';
@@ -13,12 +15,13 @@ import { withFallback } from '../utils/error-boundary';
 import {
   Dropdown,
   Firehose,
-  makeReduxID,
-  makeQuery,
   history,
   inject,
   kindObj,
+  makeQuery,
+  makeReduxID,
   PageHeading,
+  RequireCreatePermission,
 } from '../utils';
 
 export const CompactExpandButtons = ({expand = false, onExpandChange = _.noop}) => <div className="btn-group btn-group-sm" data-toggle="buttons">
@@ -30,34 +33,52 @@ export const CompactExpandButtons = ({expand = false, onExpandChange = _.noop})
   </label>
 </div>;
 
-/** @type {React.SFC<{autoFocus?: boolean, disabled?: boolean, label: string, onChange: React.ChangeEventHandler<any>, defaultValue: string}}>} */
-export const TextFilter = ({label, onChange, defaultValue, style, className, autoFocus}) => {
-  if (_.isUndefined(autoFocus)) {
-    if (window.matchMedia('(min-width: 800px)').matches) {
-      autoFocus = true;
-    } else {
-      // likely a mobile device, & autofocus will cause keyboard to pop up
-      autoFocus = false;
+/** @type {React.SFC<{disabled?: boolean, label: string, onChange: React.ChangeEventHandler<any>, defaultValue?: string, value?: string}}>} */
+export const TextFilter = ({label, onChange, defaultValue, style, className, value}) => {
+  const input = React.useRef();
+  const onKeyDown = (e) => {
+    const { nodeName } = e.target;
+    if (nodeName === 'INPUT' || nodeName === 'TEXTAREA' || e.key !== KEYBOARD_SHORTCUTS.focusFilterInput) {
+      return;
     }
-  }
-  return <input
-    autoCapitalize="none"
-    autoFocus={autoFocus}
-    className={classNames('form-control text-filter', className)}
-    defaultValue={defaultValue}
-    onChange={onChange}
-    onKeyDown={e => e.key === 'Escape' && e.target.blur()}
-    placeholder={`Filter ${label}...`}
-    style={style}
-    tabIndex={0}
-    type="text"
-  />;
+
+    e.stopPropagation();
+    e.preventDefault();
+    input.current.focus();
+  };
+
+  React.useEffect(() => {
+    window.addEventListener('keydown', onKeyDown);
+    // Remove event listeners on cleanup
+    return () => {
+      window.removeEventListener('keydown', onKeyDown);
+    };
+  }, []);
+
+  return (
+    <div className="has-feedback">
+      <input
+        ref={input}
+        autoCapitalize="none"
+        className={classNames('pf-c-form-control co-text-filter', className)}
+        value={value}
+        defaultValue={defaultValue}
+        onChange={onChange}
+        onKeyDown={e => e.key === 'Escape' && e.target.blur()}
+        placeholder={`Filter ${label}...`}
+        style={style}
+        tabIndex={0}
+        type="text"
+      />
+      <span className="form-control-feedback form-control-feedback--keyboard-hint"><kbd>/</kbd></span>
+    </div>
+  );
 };
 
 TextFilter.displayName = 'TextFilter';
 
 // TODO (jon) make this into "withListPageFilters" HOC
-/** @augments {React.PureComponent<{ListComponent: React.ComponentType<any>, kinds: string[], flatten?: function, data?: any[], rowFilters?: any[]}>} */
+/** @augments {React.PureComponent<{ListComponent: React.ComponentType<any>, kinds: string[], filters?:any, flatten?: function, data?: any[], rowFilters?: any[]}>} */
 export class ListPageWrapper_ extends React.PureComponent {
   render() {
     const {
@@ -68,7 +89,6 @@ export class ListPageWrapper_ extends React.PureComponent {
       rowFilters,
     } = this.props;
     const data = flatten ? flatten(this.props.resources) : [];
-
     const RowsOfRowFilters = rowFilters && _.map(rowFilters, ({items, reducer, selected, type, numbers}, i) => {
       const count = _.isFunction(numbers) ? numbers(data) : undefined;
       return <CheckBoxes
@@ -84,9 +104,7 @@ export class ListPageWrapper_ extends React.PureComponent {
     });
 
     return <div>
-      <div className="row">
-        {RowsOfRowFilters}
-      </div>
+      {!_.isEmpty(data) && RowsOfRowFilters}
       <div className="row">
         <div className="col-xs-12">
           <ListComponent {...this.props} data={data} />
@@ -100,12 +118,14 @@ ListPageWrapper_.displayName = 'ListPageWrapper_';
 ListPageWrapper_.propTypes = {
   data: PropTypes.array,
   kinds: PropTypes.arrayOf(PropTypes.oneOfType([PropTypes.string, PropTypes.object])).isRequired,
-  ListComponent: PropTypes.func.isRequired,
+  ListComponent: PropTypes.elementType.isRequired,
   rowFilters: PropTypes.array,
   staticFilters: PropTypes.array,
+  customData: PropTypes.any,
 };
 
-export const FireMan_ = connect(null, {filterList: k8sActions.filterList})(
+/** @type {React.FC<<WrappedComponent>, {canCreate?: Boolean, canExpand?: Boolean, textFilter:string, createAccessReview?: Object, createButtonText?: String, createProps?: Object, fieldSelector?: String, filterLabel?: String, resources: any, badge?: React.ReactNode}>*/
+export const FireMan_ = connect(null, {filterList})(
   class ConnectedFireMan extends React.PureComponent {
     constructor(props) {
       super(props);
@@ -164,39 +184,61 @@ export const FireMan_ = connect(null, {filterList: k8sActions.filterList})(
       params.forEach((v, k) => this.applyFilter(k, v));
     }
 
+    runOrNavigate = (itemName) => {
+      const { createProps = {} } = this.props;
+      const action = _.isFunction(createProps.action) && createProps.action(itemName);
+      if (action) {
+        action();
+      } else if (_.isFunction(createProps.createLink)) {
+        history.push(createProps.createLink(itemName));
+      }
+    };
+
     render() {
       const {
         autoFocus,
         canCreate,
         canExpand,
+        createAccessReview,
         createButtonText,
-        createProps,
+        createProps = {},
         filterLabel,
         helpText,
         resources,
         textFilter,
+        badge,
+        title,
       } = this.props;
 
       let createLink;
       if (canCreate) {
         if (createProps.to) {
-          createLink = <Link className="co-m-primary-action" {...createProps} tabIndex={-1}>
-            <button className="btn btn-primary" id="yaml-create">{createButtonText}</button>
+          createLink = <Link className="co-m-primary-action" {...createProps}>
+            <Button variant="primary" id="yaml-create">{createButtonText}</Button>
           </Link>;
         } else if (createProps.items) {
           createLink = <div className="co-m-primary-action">
-            <Dropdown buttonClassName="btn-primary" id="item-create" title={createButtonText} noSelection={true} items={createProps.items} onChange={(name) => history.push(createProps.createLink(name))} />
+            <Dropdown
+              buttonClassName="pf-m-primary"
+              id="item-create"
+              title={createButtonText}
+              noSelection
+              items={createProps.items}
+              onChange={this.runOrNavigate}
+            />
           </div>;
         } else {
           createLink = <div className="co-m-primary-action">
-            <button className="btn btn-primary" id="yaml-create" {...createProps}>{createButtonText}</button>
+            <Button variant="primary" id="yaml-create" {...createProps}>{createButtonText}</Button>
           </div>;
         }
+        if (!_.isEmpty(createAccessReview)) {
+          createLink = <RequireCreatePermission model={createAccessReview.model} namespace={createAccessReview.namespace}>{createLink}</RequireCreatePermission>;
+        }
       }
 
-      const {title} = this.props;
       return <React.Fragment>
-        {title && <PageHeading title={title} />}
+        {title && <PageHeading title={title} badge={badge} />}
         {/* Show help text above the filter bar if there's a create button. */}
         {helpText && createLink && <p className="co-m-pane__help-text co-help-text">{helpText}</p>}
         <div className={classNames('co-m-pane__filter-bar', {'co-m-pane__filter-bar--with-help-text': helpText && !createLink})}>
@@ -218,6 +260,7 @@ export const FireMan_ = connect(null, {filterList: k8sActions.filterList})(
             resources,
             expand: this.state.expand,
             reduxIDs: this.state.reduxIDs,
+            applyFilter:this.applyFilter,
           })}
         </div>
       </React.Fragment>;
@@ -234,6 +277,7 @@ FireMan_.defaultProps = {
 FireMan_.propTypes = {
   canCreate: PropTypes.bool,
   canExpand: PropTypes.bool,
+  createAccessReview: PropTypes.object,
   createButtonText: PropTypes.string,
   createProps: PropTypes.object,
   fieldSelector: PropTypes.string,
@@ -259,7 +303,7 @@ FireMan_.propTypes = {
   title: PropTypes.string,
 };
 
-/** @type {React.SFC<{ListComponent: React.ComponentType<any>, kind: string, helpText?: any, namespace?: string, filterLabel?: string, textFilter?: string, title?: string, showTitle?: boolean, rowFilters?: any[], selector?: any, fieldSelector?: string, canCreate?: boolean, createButtonText?: string, createProps?: any, mock?: boolean}>} */
+/** @type {React.SFC<{ListComponent: React.ComponentType<any>, kind: string, helpText?: any, namespace?: string, filterLabel?: string, textFilter?: string, title?: string, showTitle?: boolean, rowFilters?: any[], selector?: any, fieldSelector?: string, canCreate?: boolean, createButtonText?: string, createProps?: any, mock?: boolean, badge?: React.ReactNode} >} */
 export const ListPage = withFallback(props => {
   const {
     autoFocus,
@@ -279,8 +323,10 @@ export const ListPage = withFallback(props => {
     namespace,
     selector,
     showTitle = true,
+    skipAccessReview,
     textFilter,
     match,
+    badge,
   } = props;
   let { createProps } = props;
   const ko = kindObj(kind);
@@ -302,6 +348,7 @@ export const ListPage = withFallback(props => {
   }
 
   createProps = createProps || (createHandler ? {onClick: createHandler} : {to: href});
+  const createAccessReview = skipAccessReview ? null : { model: ko, namespace: usedNamespace };
   const resources = [{
     fieldSelector,
     filters,
@@ -323,9 +370,10 @@ export const ListPage = withFallback(props => {
     autoFocus={autoFocus}
     canCreate={canCreate}
     canExpand={canExpand}
+    createAccessReview={createAccessReview}
     createButtonText={createButtonText || `Create ${label}`}
     createProps={createProps}
-    filterLabel={filterLabel || `${labelPlural} by name`}
+    filterLabel={filterLabel || 'by name'}
     flatten={_resources => _.get(_resources, (name || kind), {}).data}
     helpText={helpText}
     label={labelPlural}
@@ -338,17 +386,19 @@ export const ListPage = withFallback(props => {
     showTitle={showTitle}
     textFilter={textFilter}
     title={title}
+    badge={badge}
   />;
 }, ErrorBoundaryFallback);
 
 ListPage.displayName = 'ListPage';
 
-/** @type {React.SFC<{canCreate?: boolean, createButtonText?: string, createProps?: any, flatten?: Function, title?: string, showTitle?: boolean, helpText?: any, filterLabel?: string, textFilter?: string, rowFilters?: any[], resources: any[], ListComponent: React.ComponentType<any>, namespace?: string}>} */
+/** @type {React.SFC<{canCreate?: boolean, createButtonText?: string, createProps?: any, flatten?: Function, title?: string, showTitle?: boolean, helpText?: any, filterLabel?: string, textFilter?: string, rowFilters?: any[], resources: any[], ListComponent: React.ComponentType<any>, namespace?: string, customData?: any, badge?: React.ReactNode >} */
 export const MultiListPage = props => {
   const {
     autoFocus,
     canCreate,
     canExpand,
+    createAccessReview,
     createButtonText,
     createProps,
     filterLabel,
@@ -363,6 +413,8 @@ export const MultiListPage = props => {
     staticFilters,
     textFilter,
     title,
+    customData,
+    badge,
   } = props;
 
   const resources = _.map(props.resources, (r) => ({
@@ -377,14 +429,16 @@ export const MultiListPage = props => {
     autoFocus={autoFocus}
     canCreate={canCreate}
     canExpand={canExpand}
+    createAccessReview={createAccessReview}
     createButtonText={createButtonText || 'Create'}
     createProps={createProps}
-    filterLabel={filterLabel}
+    filterLabel={filterLabel || 'by name'}
     helpText={helpText}
     resources={mock ? [] : resources}
     selectorFilterLabel="Filter by selector (app=nginx) ..."
     textFilter={textFilter}
     title={showTitle ? title : undefined}
+    badge={badge}
   >
     <Firehose resources={mock ? [] : resources}>
       <ListPageWrapper_
@@ -394,6 +448,7 @@ export const MultiListPage = props => {
         ListComponent={ListComponent}
         rowFilters={rowFilters}
         staticFilters={staticFilters}
+        customData={customData}
       />
     </Firehose>
   </FireMan_>;
