@@ -1,7 +1,4 @@
-/* eslint-disable no-undef */
 import * as _ from 'lodash-es';
-import * as classNames from 'classnames';
-import * as fuzzy from 'fuzzysearch';
 import * as PropTypes from 'prop-types';
 import * as React from 'react';
 import { connect } from 'react-redux';
@@ -13,20 +10,12 @@ import {
   List as VirtualList,
   WindowScroller,
 } from 'react-virtualized';
+import { LongArrowAltUpIcon, LongArrowAltDownIcon } from '@patternfly/react-icons';
 
-import { UIActions } from '../../ui/ui-actions';
+import * as UIActions from '../../actions/ui';
 import { ingressValidHosts } from '../ingress';
-import { routeStatus } from '../routes';
-import { secretTypeFilterReducer } from '../secret';
-import { bindingType, roleType } from '../RBAC';
+import { alertStateOrder, silenceStateOrder } from '../../reducers/monitoring';
 import {
-  alertState,
-  alertStateOrder,
-  silenceState,
-  silenceStateOrder,
-} from '../../monitoring';
-import {
-  containerLinuxUpdateOperator,
   EmptyBox,
   LabelList,
   ResourceKebab,
@@ -37,167 +26,41 @@ import {
 } from '../utils';
 import {
   getJobTypeAndCompletions,
-  nodeStatus,
   K8sKind,
   K8sResourceKind,
   K8sResourceKindReference,
   planExternalName,
   podPhase,
-  podPhaseFilterReducer,
   podReadiness,
   serviceCatalogStatus,
   serviceClassDisplayName,
   getClusterOperatorStatus,
   getClusterOperatorVersion,
+  getTemplateInstanceStatus,
+  getNodeRoles,
 } from '../../module/k8s';
 
-const fuzzyCaseInsensitive = (a, b) => fuzzy(_.toLower(a), _.toLower(b));
+import { tableFilters } from './table-filters';
 
-// TODO: Having list filters here is undocumented, stringly-typed, and non-obvious. We can change that
-const listFilters = {
-  'name': (filter, obj) => fuzzyCaseInsensitive(filter, obj.metadata.name),
-
-  'alert-name': (filter, alert) => fuzzyCaseInsensitive(filter, _.get(alert, 'labels.alertname')),
-
-  'alert-state': (filter, alert) => filter.selected.has(alertState(alert)),
-
-  'silence-name': (filter, silence) => fuzzyCaseInsensitive(filter, silence.name),
-
-  'silence-state': (filter, silence) => filter.selected.has(silenceState(silence)),
-
-  // Filter role by role kind
-  'role-kind': (filter, role) => filter.selected.has(roleType(role)),
-
-  // Filter role bindings by role kind
-  'role-binding-kind': (filter, binding) => filter.selected.has(bindingType(binding)),
-
-  // Filter role bindings by text match
-  'role-binding': (str, {metadata, roleRef, subject}) => {
-    const isMatch = val => fuzzyCaseInsensitive(str, val);
-    return [metadata.name, roleRef.name, subject.kind, subject.name].some(isMatch);
-  },
-
-  // Filter role bindings by roleRef name
-  'role-binding-roleRef': (roleRef, binding) => binding.roleRef.name === roleRef,
-
-  'selector': (selector, obj) => {
-    if (!selector || !selector.values || !selector.values.size) {
-      return true;
-    }
-    return selector.values.has(_.get(obj, selector.field));
-  },
-
-  'pod-status': (phases, pod) => {
-    if (!phases || !phases.selected || !phases.selected.size) {
-      return true;
-    }
-
-    const phase = podPhaseFilterReducer(pod);
-    return phases.selected.has(phase) || !_.includes(phases.all, phase);
-  },
-
-  'node-status': (statuses, node) => {
-    if (!statuses || !statuses.selected || !statuses.selected.size) {
-      return true;
-    }
-
-    const status = nodeStatus(node);
-    return statuses.selected.has(status) || !_.includes(statuses.all, status);
-  },
-
-  'clusterserviceversion-resource-kind': (filters, resource) => {
-    if (!filters || !filters.selected || !filters.selected.size) {
-      return true;
-    }
-    return filters.selected.has(resource.kind);
-  },
-  'clusterserviceversion-status': (filters, csv) => {
-    if (!filters || !filters.selected || !filters.selected.size) {
-      return true;
-    }
-    return filters.selected.has(_.get(csv.status, 'reason')) || !_.includes(filters.all, _.get(csv.status, 'reason'));
-  },
-
-  'packagemanifest-name': (filter, pkg) => fuzzyCaseInsensitive(filter, (pkg.status.defaultChannel
-    ? pkg.status.channels.find(ch => ch.name === pkg.status.defaultChannel)
-    : pkg.status.channels[0]).currentCSVDesc.displayName),
-
-  'build-status': (phases, build) => {
-    if (!phases || !phases.selected || !phases.selected.size) {
-      return true;
-    }
-
-    const phase = build.status.phase;
-    return phases.selected.has(phase) || !_.includes(phases.all, phase);
-  },
-
-  'build-strategy': (strategies, buildConfig) => {
-    if (!strategies || !strategies.selected || !strategies.selected.size) {
-      return true;
-    }
-
-    const strategy = buildConfig.spec.strategy.type;
-    return strategies.selected.has(strategy) || !_.includes(strategies.all, strategy);
-  },
-
-  'route-status': (statuses, route) => {
-    if (!statuses || !statuses.selected || !statuses.selected.size) {
-      return true;
-    }
-
-    const status = routeStatus(route);
-    return statuses.selected.has(status) || !_.includes(statuses.all, status);
-  },
-
-  'catalog-status': (statuses, catalog) => {
-    if (!statuses || !statuses.selected || !statuses.selected.size) {
-      return true;
-    }
-
-    const status = serviceCatalogStatus(catalog);
-    return statuses.selected.has(status) || !_.includes(statuses.all, status);
-  },
-
-  'secret-type': (types, secret) => {
-    if (!types || !types.selected || !types.selected.size) {
-      return true;
-    }
-    const type = secretTypeFilterReducer(secret);
-    return types.selected.has(type) || !_.includes(types.all, type);
-  },
-
-  'pvc-status': (phases, pvc) => {
-    if (!phases || !phases.selected || !phases.selected.size) {
-      return true;
-    }
-
-    const phase = pvc.status.phase;
-    return phases.selected.has(phase) || !_.includes(phases.all, phase);
-  },
-
-  // Filter service classes by text match
-  'service-class': (str, serviceClass) => {
-    const displayName = serviceClassDisplayName(serviceClass);
-    return fuzzyCaseInsensitive(str, displayName);
-  },
-
-  'cluster-operator-status': (statuses, operator) => {
-    if (!statuses || !statuses.selected || !statuses.selected.size) {
-      return true;
-    }
-
-    const status = getClusterOperatorStatus(operator);
-    return statuses.selected.has(status) || !_.includes(statuses.all, status);
-  },
+const rowFiltersToFilterFuncs = (rowFilters) => {
+  return (rowFilters || [])
+    .filter(f => f.type && _.isFunction(f.filter))
+    .reduce((acc, f) => ({ ...acc, [f.type]: f.filter }), {});
 };
 
-const getFilteredRows = (_filters, objects) => {
+const getAllTableFilters = (rowFilters) => ({
+  ...tableFilters,
+  ...rowFiltersToFilterFuncs(rowFilters),
+});
+
+const getFilteredRows = (_filters, rowFilters, objects) => {
   if (_.isEmpty(_filters)) {
     return objects;
   }
 
+  const allTableFilters = getAllTableFilters(rowFilters);
   _.each(_filters, (value, name) => {
-    const filter = listFilters[name];
+    const filter = allTableFilters[name];
     if (_.isFunction(filter)) {
       objects = _.filter(objects, o => filter(value, o));
     }
@@ -211,8 +74,9 @@ const filterPropType = (props, propName, componentName) => {
     return;
   }
 
+  const allTableFilters = getAllTableFilters(props.rowFilters);
   for (const key of _.keys(props[propName])) {
-    if (key in listFilters || key === 'loadTest') {
+    if (key in allTableFilters || key === 'loadTest') {
       continue;
     }
     return new Error(`Invalid prop '${propName}' in '${componentName}'. '${key}' is not a valid filter type!`);
@@ -222,7 +86,7 @@ const filterPropType = (props, propName, componentName) => {
 const sorts = {
   alertStateOrder,
   daemonsetNumScheduled: daemonset => _.toInteger(_.get(daemonset, 'status.currentNumberScheduled')),
-  dataSize: resource => _.size(_.get(resource, 'data')),
+  dataSize: resource => _.size(_.get(resource, 'data')) + _.size(_.get(resource, 'binaryData')),
   ingressValidHosts,
   serviceCatalogStatus,
   jobCompletions: job => getJobTypeAndCompletions(job).completions,
@@ -232,7 +96,6 @@ const sorts = {
     readiness = _.find(readiness, {type: 'Ready'});
     return _.get(readiness, 'status');
   },
-  nodeUpdateStatus: node => _.get(containerLinuxUpdateOperator.getUpdateStatus(node), 'text'),
   numReplicas: resource => _.toInteger(_.get(resource, 'status.replicas')),
   planExternalName,
   podPhase,
@@ -242,6 +105,11 @@ const sorts = {
   string: val => JSON.stringify(val),
   getClusterOperatorStatus,
   getClusterOperatorVersion,
+  getTemplateInstanceStatus,
+  nodeRoles: (node: K8sResourceKind): string => {
+    const roles = getNodeRoles(node);
+    return roles.sort().join(', ');
+  },
 };
 
 export class ColHead extends React.Component<ColHeadProps> {
@@ -271,13 +139,13 @@ export class ColHead extends React.Component<ColHeadProps> {
     const {
       applySort,
       children,
+      className,
       currentSortField,
       currentSortFunc,
       currentSortOrder,
       sortField,
       sortFunc,
     } = this.props;
-    const className = classNames(this.props.className, 'text-nowrap');
     if (!sortField && !sortFunc) {
       return <div className={className}>{children}</div>;
     }
@@ -287,7 +155,7 @@ export class ColHead extends React.Component<ColHeadProps> {
     const onClick = () => applySort(sortField, sortFunc, newSortOrder, children);
     return <div className={className}>
       <a className={isSorted ? undefined : 'co-m-table-grid__sort-link--unsorted'} onClick={onClick}>{children}</a>
-      {isSorted && <i className={`co-m-table-grid__sort-arrow fa fa-long-arrow-${currentSortOrder === 'asc' ? 'up' : 'down'}`}></i>}
+      {isSorted && (currentSortOrder === 'asc' ? <LongArrowAltUpIcon className="co-m-table-grid__sort-arrow" /> : <LongArrowAltDownIcon className="co-m-table-grid__sort-arrow" />)}
     </div>;
   }
 }
@@ -390,9 +258,11 @@ Rows.propTypes = {
   mock: PropTypes.bool,
 };
 
-const stateToProps = ({UI}, {data = [], defaultSortField = 'metadata.name', defaultSortFunc = undefined, filters = {}, loaded = false, reduxID = null, reduxIDs = null, staticFilters = [{}]}) => {
+const skeletonTable = <div className="loading-skeleton--table" />;
+
+const stateToProps = ({UI}, {data = [], defaultSortField = 'metadata.name', defaultSortFunc = undefined, filters = {}, loaded = false, reduxID = null, reduxIDs = null, staticFilters = [{}], rowFilters = []}) => {
   const allFilters = staticFilters ? Object.assign({}, filters, ...staticFilters) : filters;
-  let newData = getFilteredRows(allFilters, data);
+  let newData = getFilteredRows(allFilters, rowFilters, data);
 
   const listId = reduxIDs ? reduxIDs.join(',') : reduxID;
   // Only default to 'metadata.name' if no `defaultSortFunc`
@@ -418,15 +288,20 @@ const stateToProps = ({UI}, {data = [], defaultSortField = 'metadata.name', defa
     currentSortField,
     currentSortFunc,
     currentSortOrder,
+    unfilteredData: data,
     data: newData,
     listId,
   };
 };
 
-export const List = connect(stateToProps, {sortList: UIActions.sortList})(
+export const List = connect(stateToProps, {sortList: UIActions.sortList}, null, {
+  areStatesEqual: ({UI: next}, {UI: prev}) => next.get('listSorts') === prev.get('listSorts'),
+})(
   class ListInner extends React.Component<ListInnerProps> {
     static propTypes = {
       data: PropTypes.array,
+      unfilteredData: PropTypes.array,
+      AllItemsFilteredMsg: PropTypes.func,
       EmptyMsg: PropTypes.func,
       expand: PropTypes.bool,
       fieldSelector: PropTypes.string,
@@ -476,7 +351,7 @@ export const List = connect(stateToProps, {sortList: UIActions.sortList})(
       </React.Fragment>;
 
       return <div className="co-m-table-grid co-m-table-grid--bordered">
-        { mock ? children : <StatusBox {...this.props}>{children}</StatusBox> }
+        { mock ? children : <StatusBox skeleton={skeletonTable}{...this.props}>{children}</StatusBox> }
       </div>;
     }
   });
@@ -548,6 +423,7 @@ export type ListInnerProps = {
   data?: any[];
   defaultSortField?: string;
   defaultSortFunc?: string;
+  AllItemsFilteredMsg?: React.ComponentType<{}>;
   EmptyMsg?: React.ComponentType<{}>;
   expand?: boolean;
   fieldSelector?: string;
@@ -565,6 +441,7 @@ export type ListInnerProps = {
   selector?: Object;
   sortList?: (...args) => any;
   staticFilters?: any[];
+  rowFilters?: any[];
   virtualize?: boolean;
 };
 
