@@ -1,16 +1,19 @@
 import * as React from 'react';
 import * as _ from 'lodash-es';
 
-// eslint-disable-next-line no-unused-vars
 import { K8sResourceKind, K8sResourceKindReference } from '../module/k8s';
+import {ImageStreamTagModel} from '../models';
 import { DetailsPage } from './factory';
 import { Kebab, SectionHeading, navFactory, ResourceSummary } from './utils';
-import { humanizeMem } from './utils/units';
+import { humanizeBinaryBytes } from './utils/units';
+import { ExampleDockerCommandPopover } from './image-stream';
+import { ImageStreamTimeline } from './image-stream-timeline';
 
 const ImageStreamTagsReference: K8sResourceKindReference = 'ImageStreamTag';
+const ImageStreamsReference: K8sResourceKindReference = 'ImageStream';
 
 const { common } = Kebab.factory;
-const menuActions = [...common];
+const menuActions = [...Kebab.getExtensionsActionsForKind(ImageStreamTagModel), ...common];
 
 // Splits a name/value pair separated by an `=`
 const splitEnv = (nameValue: string) => {
@@ -29,7 +32,7 @@ const splitEnv = (nameValue: string) => {
   };
 };
 
-export const ImageStreamTagsDetails: React.SFC<ImageStreamTagsDetailsProps> = ({obj: imageStreamTag}) => {
+export const ImageStreamTagsDetails: React.SFC<ImageStreamTagsDetailsProps> = ({obj: imageStreamTag, imageStream}) => {
   const config = _.get(imageStreamTag, 'image.dockerImageMetadata.Config', {});
   const labels = config.Labels || {};
   // Convert to an array of objects with name and value properties, then sort the array for display.
@@ -39,8 +42,9 @@ export const ImageStreamTagsDetails: React.SFC<ImageStreamTagsDetailsProps> = ({
   const cmd = (config.Cmd || []).join(' ');
   const exposedPorts = _.keys(config.ExposedPorts).join(', ');
   const size = _.get(imageStreamTag, 'image.dockerImageMetadata.Size');
-  const humanizedSize = _.isFinite(size) && humanizeMem(size);
+  const humanizedSize = _.isFinite(size) && humanizeBinaryBytes(size).string;
   const architecture = _.get(imageStreamTag, 'image.dockerImageMetadata.Architecture');
+  const tagName = _.get(imageStreamTag, 'tag.name');
 
   return <div className="co-m-pane__body">
     <div className="co-m-pane__body-group">
@@ -55,6 +59,7 @@ export const ImageStreamTagsDetails: React.SFC<ImageStreamTagsDetailsProps> = ({
             {humanizedSize && <dt>Size</dt>}
             {humanizedSize && <dd>{humanizedSize}</dd>}
           </ResourceSummary>
+          <ExampleDockerCommandPopover imageStream={imageStream} tag={tagName} />
         </div>
         <div className="col-md-6 col-sm-12">
           <SectionHeading text="Configuration" />
@@ -123,36 +128,58 @@ export const ImageStreamTagsDetails: React.SFC<ImageStreamTagsDetailsProps> = ({
   </div>;
 };
 
-export const getImageStreamNameForTag = (imageStreamTag: K8sResourceKind): string => {
-  const name = _.get(imageStreamTag, 'metadata.name', '');
-  return name.split(':')[0];
+const parseName = (nameAndTag: string): string => {
+  return nameAndTag.split(':')[0];
 };
 
-const pages = [navFactory.details(ImageStreamTagsDetails), navFactory.editYaml()];
+const getImageStreamNameAndTag = (imageStreamTag: K8sResourceKind) => {
+  const imageStreamTagName: string = _.get(imageStreamTag, 'metadata.name') || '';
+  const [ imageStreamName, tag ] = imageStreamTagName.split(':');
+  return { imageStreamName, tag };
+};
+
+const ImageStreamTagHistory: React.FC<ImageStreamTagHistoryProps> = ({ obj: imageStreamTag, imageStream }) => {
+  const { tag } = getImageStreamNameAndTag(imageStreamTag);
+  const imageStreamStatusTags = _.filter(_.get(imageStream, 'status.tags'), i => i.tag === tag);
+  return <ImageStreamTimeline imageStreamTags={imageStreamStatusTags} imageStreamName={imageStream.metadata.name} imageStreamNamespace={imageStream.metadata.namespace} />;
+};
+ImageStreamTagHistory.displayName = 'ImageStreamTagHistory';
+
+const pages = [navFactory.details(ImageStreamTagsDetails), navFactory.editYaml(), navFactory.history(ImageStreamTagHistory)];
 export const ImageStreamTagsDetailsPage: React.SFC<ImageStreamTagsDetailsPageProps> = props =>
   <DetailsPage
     {...props}
     breadcrumbsFor={obj => {
-      const imageStreamName = getImageStreamNameForTag(obj);
-      return [{
-        name: imageStreamName,
-        path: `/k8s/ns/${obj.metadata.namespace}/imagestreams/${imageStreamName}`,
+      const { imageStreamName } = getImageStreamNameAndTag(obj);
+      return [{name: 'Image Streams', path: `/k8s/ns/${props.match.params.ns}/imagestreams`,
       }, {
-        name: 'ImageStreamTag Details',
+        name: imageStreamName,
+        path: `/k8s/ns/${props.match.params.ns}/imagestreams/${imageStreamName}`,
+      }, {
+        name: 'Image Stream Tag Details',
         path: props.match.url,
       }];
     }}
     kind={ImageStreamTagsReference}
     menuActions={menuActions}
+    resources={[
+      {kind: ImageStreamsReference, name: parseName(props.name), namespace: props.namespace, isList: false, prop: 'imageStream'},
+    ]}
     pages={pages} />;
 ImageStreamTagsDetailsPage.displayName = 'ImageStreamTagsDetailsPage';
 
-/* eslint-disable no-undef */
+type ImageStreamTagHistoryProps = {
+  imageStream: K8sResourceKind;
+  obj: K8sResourceKind;
+}
+
 export type ImageStreamTagsDetailsProps = {
-  obj: any,
+  obj: K8sResourceKind;
+  imageStream: K8sResourceKind;
 };
 
 export type ImageStreamTagsDetailsPageProps = {
-  match: any,
+  match: any;
+  namespace: string;
+  name: string;
 };
-/* eslint-enable no-undef */
