@@ -1,46 +1,80 @@
 import * as _ from 'lodash-es';
 import * as React from 'react';
 import { Link } from 'react-router-dom';
+import { sortable } from '@patternfly/react-table';
+import * as classNames from 'classnames';
+import { connectToFlags } from '../reducers/features';
+import { FLAGS } from '../const';
+import { DetailsPage, ListPage, Table, TableRow, TableData } from './factory';
+import { Kebab, navFactory, ResourceKebab, SectionHeading, ResourceLink, ResourceSummary, Selector, ExternalLink } from './utils';
+import { NetworkPolicyModel } from '../models';
 
-import { FLAGS, connectToFlags } from '../features';
-import { ColHead, DetailsPage, List, ListHeader, ListPage } from './factory';
-import { Cog, navFactory, ResourceCog, SectionHeading, ResourceLink, ResourceSummary, Selector, helpLink, HELP_TOPICS } from './utils';
+const { common } = Kebab.factory;
+const menuActions = [...Kebab.getExtensionsActionsForKind(NetworkPolicyModel), ...common];
 
-const menuActions = [Cog.factory.ModifyLabels, Cog.factory.ModifyAnnotations, Cog.factory.Edit, Cog.factory.Delete];
+const tableColumnClasses = [
+  classNames('col-sm-4', 'col-xs-6'),
+  classNames('col-sm-4', 'col-xs-6'),
+  classNames('col-sm-4', 'hidden-xs'),
+  Kebab.columnClass,
+];
 
-const Header = props => <ListHeader>
-  <ColHead {...props} className="col-xs-4" sortField="metadata.name">Name</ColHead>
-  <ColHead {...props} className="col-xs-3" sortField="metadata.namespace">Namespace</ColHead>
-  <ColHead {...props} className="col-xs-5" sortField="spec.podSelector">Pod Selector</ColHead>
-</ListHeader>;
+const NetworkPolicyTableHeader = () => {
+  return [
+    {
+      title: 'Name', sortField: 'metadata.name', transforms: [sortable],
+      props: { className: tableColumnClasses[0] },
+    },
+    {
+      title: 'Namespace', sortField: 'metadata.namespace', transforms: [sortable],
+      props: { className: tableColumnClasses[1] },
+    },
+    {
+      title: 'Pod Selector', sortField: 'spec.podSelector', transforms: [sortable],
+      props: { className: tableColumnClasses[2] },
+    },
+    {
+      title: '', props: { className: tableColumnClasses[3] },
+    },
+  ];
+};
+NetworkPolicyTableHeader.displayName = 'NetworkPolicyTableHeader';
 
 const kind = 'NetworkPolicy';
-const Row = ({obj: np}) => <div className="row co-resource-list__item">
-  <div className="col-xs-4 co-resource-link-wrapper">
-    <ResourceCog actions={menuActions} kind={kind} resource={np} />
-    <ResourceLink kind={kind} name={np.metadata.name} namespace={np.metadata.namespace} title={np.metadata.name} />
-  </div>
-  <div className="col-xs-3 co-break-word">
-    <ResourceLink kind={'Namespace'} name={np.metadata.namespace} title={np.metadata.namespace} />
-  </div>
 
-  <div className="col-xs-5 co-break-word">
-    {
-      _.isEmpty(np.spec.podSelector) ?
-        <Link to={`/search/ns/${np.metadata.namespace}?kind=Pod`}>{`All pods within ${np.metadata.namespace}`}</Link> :
-        <Selector selector={np.spec.podSelector} namespace={np.metadata.namespace} />
-    }
-  </div>
-</div>;
+const NetworkPolicyTableRow = ({obj: np, index, key, style}) => {
+  return (
+    <TableRow id={np.metadata.uid} index={index} trKey={key} style={style}>
+      <TableData className={tableColumnClasses[0]}>
+        <ResourceLink kind={kind} name={np.metadata.name} namespace={np.metadata.namespace} title={np.metadata.name} />
+      </TableData>
+      <TableData className={classNames(tableColumnClasses[1], 'co-break-word')}>
+        <ResourceLink kind={'Namespace'} name={np.metadata.namespace} title={np.metadata.namespace} />
+      </TableData>
+      <TableData className={classNames(tableColumnClasses[2], 'co-break-word')}>
+        {
+          _.isEmpty(np.spec.podSelector) ?
+            <Link to={`/search/ns/${np.metadata.namespace}?kind=Pod`}>{`All pods within ${np.metadata.namespace}`}</Link> :
+            <Selector selector={np.spec.podSelector} namespace={np.metadata.namespace} />
+        }
+      </TableData>
+      <TableData className={tableColumnClasses[3]}>
+        <ResourceKebab actions={menuActions} kind={kind} resource={np} />
+      </TableData>
+    </TableRow>
+  );
+};
+NetworkPolicyTableRow.displayName = 'NetworkPolicyTableRow';
+
+const NetworkPoliciesList = props => <Table {...props} aria-label="Network Policies" Header={NetworkPolicyTableHeader} Row={NetworkPolicyTableRow} virtualize />;
 
-const NetworkPoliciesList = props => <List {...props} Header={Header} Row={Row} />;
 export const NetworkPoliciesPage = props => <ListPage {...props} ListComponent={NetworkPoliciesList} kind={kind} canCreate={true} />;
 
 
 const IngressHeader = () => <div className="row co-m-table-grid__head">
-  <div className="col-xs-4">target pods</div>
-  <div className="col-xs-5">from</div>
-  <div className="col-xs-3">to ports</div>
+  <div className="col-xs-4">Target Pods</div>
+  <div className="col-xs-5">From</div>
+  <div className="col-xs-3">To Ports</div>
 </div>;
 
 const IngressRow = ({ingress, namespace, podSelector}) => {
@@ -89,14 +123,12 @@ const IngressRow = ({ingress, namespace, podSelector}) => {
   </div>;
 };
 
-const Details_ = ({flags, obj: np}) => {
-  const networkPolicyDocs = flags[FLAGS.OPENSHIFT]
-    ? helpLink(HELP_TOPICS.NETWORK_POLICY_GUIDE)
-    : 'https://kubernetes.io/docs/concepts/services-networking/network-policies/';
+const Details_ = ({obj: np}) => {
+  const networkPolicyDocs = 'https://kubernetes.io/docs/concepts/services-networking/network-policies/';
   return <React.Fragment>
     <div className="co-m-pane__body">
       <SectionHeading text="Namespace Overview" />
-      <ResourceSummary resource={np} podSelector={'spec.podSelector'} showNodeSelector={false} />
+      <ResourceSummary resource={np} podSelector={'spec.podSelector'} showPodSelector />
     </div>
     <div className="co-m-pane__body">
       <SectionHeading text="Ingress Rules" />
@@ -104,7 +136,7 @@ const Details_ = ({flags, obj: np}) => {
         Pods accept all traffic by default.
         They can be isolated via Network Policies which specify a whitelist of ingress rules.
         When a Pod is selected by a Network Policy, it will reject all traffic not explicitly allowed via a Network Policy.
-        See more details in <a target="_blank" rel="noopener noreferrer" href={networkPolicyDocs}>Network Policies Documentation</a>.
+        See more details in <ExternalLink href={networkPolicyDocs} text="Network Policies Documentation" />.
       </p>
       {
         _.isEmpty(_.get(np, 'spec.ingress[0]', [])) ?
