@@ -1,12 +1,13 @@
 import * as React from 'react';
 import * as _ from 'lodash-es';
+import LazyLoad from 'react-lazyload';
 import { Modal } from 'patternfly-react';
 import { CatalogTile } from 'patternfly-react-extensions';
 
+import * as operatorLogo from '../../imgs/operator.svg';
 import { GreenCheckCircleIcon } from '@console/shared';
 import { history } from '../utils/router';
 import { COMMUNITY_PROVIDERS_WARNING_LOCAL_STORAGE_KEY } from '../../const';
-import { normalizeIconClass } from '../catalog/catalog-item-icon';
 import { TileViewPage } from '../utils/tile-view-page';
 import { OperatorHubItemDetails } from './operator-hub-item-details';
 import { communityOperatorWarningModal } from './operator-hub-community-provider-modal';
@@ -256,18 +257,26 @@ export const OperatorHubTileView: React.FC<OperatorHubTileViewProps> = (props) =
       return null;
     }
 
-    const {uid, name, imgUrl, iconClass, provider, description, installed} = item;
-    const normalizedIconClass = iconClass && `icon ${normalizeIconClass(iconClass)}`;
+    const {uid, name, imgUrl, provider, description, installed} = item;
     const vendor = provider ? `provided by ${provider}` : null;
     const badges = [COMMUNITY_PROVIDER_TYPE, CUSTOM_PROVIDER_TYPE].includes(item.providerType) ? [badge(item.providerType)] : [];
 
+    const icon = (
+      <LazyLoad
+        once
+        placeholder={<img className="catalog-tile-pf-icon" src={operatorLogo} alt="" />}
+        scrollContainer="#content-scrollable"
+      >
+        <img className="catalog-tile-pf-icon" src={imgUrl} alt="" />
+      </LazyLoad>
+    );
+
     return (
       <CatalogTile
         key={uid}
         title={name}
         badges={badges}
-        iconImg={imgUrl}
-        iconClass={normalizedIconClass}
+        icon={icon}
         vendor={vendor}
         description={description}
         onClick={() => openOverlay(item)}
