@@ -2,8 +2,11 @@ import * as _ from 'lodash-es';
 import * as React from 'react';
 import * as classNames from 'classnames';
 import * as PropTypes from 'prop-types';
-
-import { history, ResourceName } from './index';
+import { connect } from 'react-redux';
+import { CaretDownIcon, MinusCircleIcon, PlusCircleIcon, StarIcon } from '@patternfly/react-icons';
+import { impersonateStateToProps } from '../../reducers/ui';
+import { checkAccess, history, KebabItems, ResourceName } from './index';
+import { useSafetyFirst } from '../safety-first';
 
 export class DropdownMixin extends React.PureComponent {
   constructor(props) {
@@ -46,22 +49,31 @@ export class DropdownMixin extends React.PureComponent {
     e.preventDefault();
     e.stopPropagation();
 
-    const {onChange, noSelection, title} = this.props;
+    const { items, actionItems, onChange, noSelection, title } = this.props;
 
     if (onChange) {
       onChange(selectedKey, e);
     }
 
-    this.setState({
-      selectedKey,
-      title: noSelection ? title : this.props.items[selectedKey],
-    });
+    const newTitle = items[selectedKey];
+
+    if (!actionItems || !_.some(actionItems, {actionKey: selectedKey})) {
+      this.setState({
+        selectedKey,
+        title: noSelection ? title : newTitle,
+      });
+    }
 
     this.hide();
   }
 
   toggle(e) {
     e.preventDefault();
+
+    if (this.props.disabled) {
+      return;
+    }
+
     if (this.state.active) {
       this.hide(e);
     } else {
@@ -86,28 +98,33 @@ export class DropdownMixin extends React.PureComponent {
   }
 }
 
-const Caret = () => <span className="caret" />;
-
 class DropDownRow extends React.PureComponent {
   render() {
-    const {itemKey, content, onclick, onBookmark, onUnBookmark, className, selected, hover, canFavorite, onFavorite, favoriteKey} = this.props;
+    const {itemKey, content, onclick, onBookmark, onUnBookmark, className, selected, hover, canFavorite, onFavorite, favoriteKey, autocompleteFilter} = this.props;
     let prefix;
+
+    if (!autocompleteFilter && !onBookmark && !onUnBookmark) {
+      //use pf4 markup if not using the autocomplete dropdown
+      return <li key={itemKey}>
+        <button className="pf-c-dropdown__menu-item" id={`${itemKey}-link`} data-test-id="dropdown-menu" onClick={e => onclick(itemKey, e)}>{content}</button>
+      </li>;
+    }
     if (onUnBookmark) {
-      prefix = <a href="#" className={classNames('bookmarker', {hover, focus: selected})} onClick={e => onUnBookmark(e, itemKey)}><i aria-hidden className="fa fa-minus-circle" /></a>;
+      prefix = <a href="#" className={classNames('bookmarker', {hover, focus: selected})} onClick={e => onUnBookmark(e, itemKey)}><MinusCircleIcon /></a>;
     }
     if (onBookmark) {
-      prefix = <a href="#" className={classNames('bookmarker', {hover, focus: selected})} onClick={e => onBookmark(e, itemKey, content)}><i aria-hidden className="fa fa-plus-circle" /></a>;
+      prefix = <a href="#" className={classNames('bookmarker', {hover, focus: selected})} onClick={e => onBookmark(e, itemKey, content)}><PlusCircleIcon /></a>;
     }
 
     let suffix;
     if (onUnBookmark && canFavorite) {
       const isFavorite = favoriteKey === itemKey;
-      suffix = <a href="#" className={classNames('bookmarker', {hover, focus: selected})} onClick={e => onFavorite(e, (isFavorite ? undefined : itemKey))}><i aria-hidden className={classNames('fa fa-star', {'favorite': isFavorite})} /></a>;
+      suffix = <a href="#" className={classNames('bookmarker', {hover, focus: selected})} onClick={e => onFavorite(e, (isFavorite ? undefined : itemKey))}><StarIcon className={classNames({'favorite': isFavorite})} /></a>;
     }
 
     return <li role="option" className={classNames(className)} key={itemKey}>
       {prefix}
-      <a href="#" ref={this.link} id={`${itemKey}-link`} className={classNames({'next-to-bookmark': !!prefix, hover, focus: selected})} onClick={e => onclick(itemKey, e)}>{content}</a>
+      <a href="#" ref={this.link} id={`${itemKey}-link`} className={classNames('pf-c-dropdown__menu-item', {'next-to-bookmark': !!prefix, hover, focus: selected})} onClick={e => onclick(itemKey, e)}>{content}</a>
       {suffix}
     </li>;
   }
@@ -144,9 +161,10 @@ export class Dropdown extends DropdownMixin {
 
     this.state.items = Object.assign({}, bookmarks, props.items);
 
+    const defaultTitle = React.isValidElement(props.title) ? props.title : <span className="pf-c-dropdown__toggle-text--placeholder">{props.title}</span>;
     this.state.title = props.noSelection
       ? props.title
-      : _.get(props.items, props.selectedKey, <span className="btn-dropdown__item--placeholder">{props.title}</span>);
+      : _.get(props.items, props.selectedKey, defaultTitle);
 
     this.onKeyDown = e => this.onKeyDown_(e);
     this.changeTextFilter = e => this.applyTextFilter_(e.target.value, this.props.items);
@@ -291,9 +309,34 @@ export class Dropdown extends DropdownMixin {
     localStorage.setItem(this.bookmarkStorageKey, JSON.stringify(bookmarks));
   }
 
+  renderActionItem() {
+    const { actionItems } = this.props;
+    if (actionItems) {
+      const { selectedKey, keyboardHoverKey, noSelection } = this.props;
+      return (
+        <React.Fragment>
+          {actionItems.map((ai) =>
+            <DropDownRow
+              className={classNames({'active': (ai.actionKey === selectedKey) && !noSelection})}
+              key={`${ai.actionKey}-${ai.actionTitle}`}
+              itemKey={ai.actionKey}
+              content={ai.actionTitle}
+              onclick={this.onClick}
+              selected={(ai.actionKey === selectedKey) && !noSelection}
+              hover={ai.actionKey === keyboardHoverKey} />
+          )}
+          <li className="co-namespace-selector__divider">
+            <div className="dropdown-menu__divider" />
+          </li>
+        </React.Fragment>
+      );
+    }
+    return null;
+  }
+
   render() {
     const {active, autocompleteText, selectedKey, items, title, bookmarks, keyboardHoverKey, favoriteKey} = this.state;
-    const {autocompleteFilter, autocompletePlaceholder, className, buttonClassName, menuClassName, storageKey, canFavorite, dropDownClassName, titlePrefix, describedBy} = this.props;
+    const {autocompleteFilter, autocompletePlaceholder, className, buttonClassName, menuClassName, storageKey, canFavorite, dropDownClassName, titlePrefix, describedBy, disabled} = this.props;
 
     const spacerBefore = this.props.spacerBefore || new Set();
     const headerBefore = this.props.headerBefore || {};
@@ -315,50 +358,77 @@ export class Dropdown extends DropdownMixin {
       if (_.has(headerBefore, key)) {
         rows.push(<li key={`${key}-header`}><div className="dropdown-menu__header" >{headerBefore[key]}</div></li>);
       }
-      rows.push(<DropDownRow className={klass} key={key} itemKey={key} content={content} onBookmark={storageKey && this.onBookmark} onclick={this.onClick} selected={selected} hover={hover} />);
+      rows.push(<DropDownRow className={klass} key={key} itemKey={key} content={content} onBookmark={storageKey && this.onBookmark} onclick={this.onClick} selected={selected} hover={hover} autocompleteFilter={autocompleteFilter} />);
     };
 
     _.each(items, (v, k) => addItem(k, v));
 
-    return <div className={classNames(className)} ref={this.dropdownElement} style={this.props.style}>
-      <div className={classNames('dropdown', dropDownClassName)}>
-        <button aria-haspopup="true" onClick={this.toggle} onKeyDown={this.onKeyDown} type="button" className={classNames('btn', 'btn-dropdown', 'dropdown-toggle', buttonClassName ? buttonClassName : 'btn-default')} id={this.props.id} aria-describedby={describedBy} >
-          <div className="btn-dropdown__content-wrap">
-            <span className="btn-dropdown__item">
-              {titlePrefix && <span className="btn-link__titlePrefix">{titlePrefix}: </span>}
-              {title}
-            </span>
-            <Caret />
-          </div>
+    //render PF4 dropdown markup if this is not the autocomplete filter
+    if (autocompleteFilter) {
+      return <div className={className} ref={this.dropdownElement} style={this.props.style}>
+        <div className={classNames('dropdown pf-c-dropdown', {'pf-m-expanded': this.state.active}, dropDownClassName)}>
+          <button aria-haspopup="true" onClick={this.toggle} onKeyDown={this.onKeyDown} type="button" className={classNames('pf-c-dropdown__toggle', buttonClassName)} id={this.props.id} aria-describedby={describedBy} disabled={disabled} >
+            <div className="btn-dropdown__content-wrap">
+              <span className="pf-c-dropdown__toggle-text">
+                {titlePrefix && <span className="btn-link__titlePrefix">{titlePrefix}: </span>}
+                {title}
+              </span>
+              <CaretDownIcon className="pf-c-dropdown__toggle-icon" />
+            </div>
+          </button>
+          {
+            active && <ul role="listbox" ref={this.dropdownList} className={classNames('dropdown-menu__autocomplete-filter', 'pf-c-dropdown__menu', menuClassName)}>
+              {
+                autocompleteFilter && <div className="dropdown-menu__filter">
+                  <input
+                    autoFocus
+                    type="text"
+                    ref={input => this.input = input}
+                    onChange={this.changeTextFilter}
+                    placeholder={autocompletePlaceholder}
+                    value={autocompleteText || ''}
+                    autoCapitalize="none"
+                    onKeyDown={this.onKeyDown}
+                    className="pf-c-form-control"
+                    onClick={e => e.stopPropagation()}
+                    data-test-id="dropdown-text-filter" />
+                </div>
+              }
+              { this.renderActionItem() }
+              { bookMarkRows }
+              {_.size(bookMarkRows) ? <li className="co-namespace-selector__divider"><div className="dropdown-menu__divider" /></li> : null}
+              {rows}
+            </ul>
+          }
+        </div>
+      </div>;
+    }
+
+    //pf4 markup
+    return (<div className={className} ref={this.dropdownElement} style={this.props.style}>
+      <div className={classNames({'dropdown pf-c-dropdown': true, 'pf-m-expanded': this.state.active}, dropDownClassName)}>
+        <button aria-haspopup="true" aria-expanded={this.state.active} className={classNames('pf-c-dropdown__toggle', buttonClassName)} data-test-id="dropdown-button" onClick={this.toggle} onKeyDown={this.onKeyDown} type="button" id={this.props.id} aria-describedby={describedBy} >
+          <span className="pf-c-dropdown__toggle-text">
+            {titlePrefix && <span className="btn-link__titlePrefix">{titlePrefix}: </span>}
+            {title}
+          </span>
+          <CaretDownIcon className="pf-c-dropdown__toggle-icon" />
         </button>
         {
-          active && <ul role="listbox" ref={this.dropdownList} className={classNames('dropdown-menu', 'dropdown-menu--block', menuClassName)}>
-            {
-              autocompleteFilter && <div className="dropdown-menu__filter">
-                <input
-                  autoFocus
-                  type="text"
-                  ref={input => this.input = input}
-                  onChange={this.changeTextFilter}
-                  placeholder={autocompletePlaceholder}
-                  value={autocompleteText || ''}
-                  autoCapitalize="none"
-                  onKeyDown={this.onKeyDown}
-                  className="form-control dropdown--text-filter"
-                  onClick={e => e.stopPropagation()} />
-              </div>
-            }
-            { bookMarkRows }
-            {_.size(bookMarkRows) ? <li className="co-namespace-selector__divider"><div className="dropdown-menu__divider" /></li> : null}
+          active && <ul ref={this.dropdownList} className={classNames('pf-c-dropdown__menu', menuClassName)}>
             {rows}
           </ul>
         }
       </div>
-    </div>;
+    </div>);
   }
 }
 
 Dropdown.propTypes = {
+  actionItems: PropTypes.arrayOf(PropTypes.shape({
+    actionKey: PropTypes.string,
+    actionTitle: PropTypes.string,
+  })),
   autocompleteFilter: PropTypes.func,
   autocompletePlaceholder: PropTypes.string,
   canFavorite: PropTypes.bool,
@@ -375,31 +445,69 @@ Dropdown.propTypes = {
   spacerBefore: PropTypes.instanceOf(Set),
   textFilter: PropTypes.string,
   title: PropTypes.node,
+  disabled: PropTypes.bool,
 };
 
-export const ActionsMenu = (props) => {
-  const {actions, title = undefined, menuClassName = undefined, buttonClassName = undefined} = props;
-  const shownActions = _.reject(actions, 'hidden');
-  const items = _.fromPairs(_.map(shownActions, (v, k) => [k, v.label]));
-  const btnTitle = title || <span id="action-dropdown">Actions</span>;
-  const onChange = (key, e) => {
-    const action = shownActions[key];
-    if (action.callback) {
-      return action.callback(e);
+class ActionsMenuDropdown extends DropdownMixin {
+  render() {
+    const {actions, title = undefined} = this.props;
+    const onClick = (event, option) => {
+      event.preventDefault();
+
+      if (option.callback) {
+        option.callback();
+      }
+
+      if (option.href) {
+        history.push(option.href);
+      }
+
+      this.hide();
+    };
+    return <div ref={this.dropdownElement} className={classNames({'co-actions-menu pf-c-dropdown': true, 'pf-m-expanded': this.state.active})}>
+      <button type="button" aria-haspopup="true" aria-label="Actions" aria-expanded={this.state.active} className="pf-c-dropdown__toggle" onClick={this.toggle} data-test-id="actions-menu-button">
+        <span className="pf-c-dropdown__toggle-text">
+          {title || 'Actions'}
+        </span>
+        <CaretDownIcon className="pf-c-dropdown__toggle-icon" />
+      </button>
+      {this.state.active && <KebabItems options={actions} onClick={onClick} />}
+    </div>;
+  }
+}
+
+const ActionsMenu_ = ({actions, impersonate, title = undefined}) => {
+  const [isVisible, setVisible] = useSafetyFirst(false);
+
+  // Check if any actions are visible when actions have access reviews.
+  React.useEffect(() => {
+    if (!actions.length) {
+      setVisible(false);
+      return;
     }
-    if (action.href) {
-      history.push(action.href);
+
+    const promises = actions.reduce((acc, action) => {
+      if (action.accessReview) {
+        acc.push(checkAccess(action.accessReview));
+      }
+      return acc;
+    }, []);
+
+    if (_.isEmpty(promises)) {
+      setVisible(true);
+      return;
     }
-  };
-  return <Dropdown
-    buttonClassName={buttonClassName}
-    className="co-actions-menu"
-    menuClassName={menuClassName || 'dropdown-menu-right'}
-    items={items}
-    title={btnTitle}
-    onChange={onChange}
-    noSelection={true} />;
+
+    Promise.all(promises)
+      .then((results) => setVisible(_.some(results, 'status.allowed')))
+      .catch(() => setVisible(true));
+  }, [actions, impersonate, setVisible]);
+
+  return isVisible
+    ? <ActionsMenuDropdown actions={actions} title={title} />
+    : null;
 };
+export const ActionsMenu = connect(impersonateStateToProps)(ActionsMenu_);
 
 ActionsMenu.propTypes = {
   actions: PropTypes.arrayOf(
@@ -407,8 +515,8 @@ ActionsMenu.propTypes = {
       label: PropTypes.node.isRequired,
       href: PropTypes.string,
       callback: PropTypes.func,
+      accessReview: PropTypes.object,
     })).isRequired,
-  menuClassName: PropTypes.string,
   title: PropTypes.node,
 };
 
