@@ -589,7 +589,7 @@ export class TileViewPage extends React.Component {
     </VerticalTabs>;
   }
 
-  // eslint-disable-next-line no-unused-vars
+  // eslint-disable-next-line @typescript-eslint/no-unused-vars, no-unused-vars
   renderFilterGroup(filterGroup, groupName, activeFilters, filterCounts, onFilterChange, onUpdateFilters) {
     const { filterGroupNameMap } = this.props;
     const { filterGroupsShowAll } = this.state;
@@ -627,16 +627,6 @@ export class TileViewPage extends React.Component {
 
     return (
       <FilterSidePanel>
-        <FilterSidePanel.Category key="keyword" onSubmit={(e) => e.preventDefault()}>
-          <FormControl
-            type="text"
-            inputRef={(ref) => this.filterByKeywordInput = ref}
-            placeholder="Filter by keyword..."
-            bsClass="form-control"
-            value={activeFilters.keyword.value}
-            onChange={e => this.onKeywordChange(e.target.value)}
-          />
-        </FilterSidePanel.Category>
         {_.map(activeFilters, (filterGroup, groupName) => {
           if (groupName === 'keyword') {
             return;
@@ -665,39 +655,43 @@ export class TileViewPage extends React.Component {
   }
 
   render() {
-    const { renderTile, pageDescription } = this.props;
-    const { selectedCategoryId, categories } = this.state;
+    const { renderTile } = this.props;
+    const { activeFilters, selectedCategoryId, categories } = this.state;
     let activeCategory = findActiveCategory(selectedCategoryId, categories);
     if (!activeCategory) {
       activeCategory = findActiveCategory('all', categories);
     }
 
     return (
-      <React.Fragment>
-        {pageDescription && (
-          <p className="co-catalog-page__description">
-            {pageDescription}
-          </p>
-        )}
-        <div className="co-catalog-page">
-          <div className="co-catalog-page__tabs">
-            { this.renderCategoryTabs(activeCategory.id) }
-            { this.renderSidePanel() }
-          </div>
-          <div className="co-catalog-page__content">
-            <div>
-              <div className="co-catalog-page__heading text-capitalize">{activeCategory.label}</div>
+      <div className="co-catalog-page">
+        <div className="co-catalog-page__tabs">
+          { this.renderCategoryTabs(activeCategory.id) }
+          { this.renderSidePanel() }
+        </div>
+        <div className="co-catalog-page__content">
+          <div className="co-catalog-page__header">
+            <div className="co-catalog-page__heading text-capitalize">{activeCategory.label}</div>
+            <div className="co-catalog-page__filter">
+              <FormControl
+                className="co-catalog-page__input"
+                type="text"
+                inputRef={(ref) => this.filterByKeywordInput = ref}
+                placeholder="Filter by keyword..."
+                bsClass="pf-c-form-control"
+                value={activeFilters.keyword.value}
+                onChange={e => this.onKeywordChange(e.target.value)}
+              />
               <div className="co-catalog-page__num-items">{activeCategory.numItems} items</div>
             </div>
-            {activeCategory.numItems > 0 && (
-              <div className="catalog-tile-view-pf catalog-tile-view-pf-no-categories">
-                {_.map(activeCategory.items, item => renderTile(item))}
-              </div>
-            )}
-            {activeCategory.numItems === 0 && this.renderEmptyState()}
           </div>
+          {activeCategory.numItems > 0 && (
+            <div className="catalog-tile-view-pf catalog-tile-view-pf-no-categories">
+              {_.map(activeCategory.items, item => renderTile(item))}
+            </div>
+          )}
+          {activeCategory.numItems === 0 && this.renderEmptyState()}
         </div>
-      </React.Fragment>
+      </div>
     );
   }
 }
@@ -714,7 +708,6 @@ TileViewPage.propTypes = {
   renderFilterGroup: PropTypes.func,
   keywordCompare: PropTypes.func.isRequired,
   renderTile: PropTypes.func.isRequired,
-  pageDescription: PropTypes.oneOfType([PropTypes.string, PropTypes.node]),
   emptyStateTitle: PropTypes.string,
   emptyStateInfo: PropTypes.string,
 };
@@ -724,7 +717,6 @@ TileViewPage.defaultProps = {
   getAvailableFilters: determineAvailableFilters,
   filterGroupNameMap: {},
   renderFilterGroup: null,
-  pageDescription: null,
   emptyStateTitle: 'No Results Match the Filter Criteria',
   emptyStateInfo: 'No items are being shown due to the filters being applied.',
 };
