@@ -9,11 +9,6 @@ const TYPES = {
     space: false,
     divisor: 1000,
   },
-  percentage: {
-    units: ['%'],
-    space: false,
-    divisor: 1000,
-  },
   decimalBytes: {
     units: ['B', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB'],
     space: true,
@@ -35,10 +30,20 @@ const TYPES = {
     divisor: 1024,
   },
   SI: {
-    units: ['', 'K', 'M', 'G', 'T', 'P', 'E'],
+    units: ['', 'k', 'M', 'G', 'T', 'P', 'E'],
     space: false,
     divisor: 1000,
   },
+  decimalBytesPerSec: {
+    units: ['Bps', 'KBps', 'MBps', 'GBps', 'TBps', 'PBps', 'EBps'],
+    space: true,
+    divisor: 1000,
+  },
+  seconds: {
+    units: ['ns', 'μs', 'ms', 's'],
+    space: true,
+    divisor: 1000,
+  },
 };
 
 const getType = (name) => {
@@ -53,9 +58,20 @@ const getType = (name) => {
   return type;
 };
 
-const convertBaseValueToUnits = (value, unitArray, divisor, initialUnit) => {
+const convertBaseValueToUnits = (value, unitArray, divisor, initialUnit, preferredUnit) => {
   const sliceIndex = initialUnit ? unitArray.indexOf(initialUnit) : 0;
   const units_ = unitArray.slice(sliceIndex);
+
+  if (preferredUnit || preferredUnit === '') {
+    const unitIndex = units_.indexOf(preferredUnit);
+    if (unitIndex !== -1) {
+      return {
+        value: value / divisor ** unitIndex,
+        unit: preferredUnit,
+      };
+    }
+  }
+
   let unit = units_.shift();
   while (value >= divisor && units_.length > 0) {
     value = value / divisor;
@@ -101,53 +117,99 @@ const convertValueWithUnitsToBaseValue = (value, unitArray, divisor) => {
   return { value, unit };
 };
 
-const round = units.round = (value) => {
+const getDefaultFractionDigits = value => {
+  if (value < 1) {
+    return 3;
+  }
+  if (value < 100) {
+    return 2;
+  }
+  return 1;
+};
+
+const formatValue = (value, options) => {
+  const fractionDigits = getDefaultFractionDigits(value);
+  const {locales, ...rest} = _.defaults(options, {
+    maximumFractionDigits: fractionDigits,
+  });
+
+  if (!isFinite(value)) {
+    return Intl.NumberFormat(locales, rest).format(0);
+  }
+  return Intl.NumberFormat(locales, rest).format(value);
+};
+
+const round = units.round = (value, fractionDigits) => {
   if (!isFinite(value)) {
     return 0;
   }
-  let digits;
-  if (value >= 100) {
-    digits = 1;
-  } else if (value >= 1) {
-    digits = 2;
-  } else {
-    digits = 3;
-  }
-  const multiplier = Math.pow(10, digits);
+  const multiplier = Math.pow(10, fractionDigits || getDefaultFractionDigits(value));
   return Math.round(value * multiplier) / multiplier;
 };
 
-const humanize = units.humanize = (value, typeName, useRound = false) => {
+const humanize = units.humanize = (value, typeName, useRound = false, initialUnit, preferredUnit) => {
   const type = getType(typeName);
 
   if (!isFinite(value)) {
     value = 0;
   }
 
-  let converted = convertBaseValueToUnits(value, type.units, type.divisor);
+  let converted = convertBaseValueToUnits(value, type.units, type.divisor, initialUnit, preferredUnit);
 
   if (useRound) {
     converted.value = round(converted.value);
-    converted = convertBaseValueToUnits(converted.value, type.units, type.divisor, converted.unit);
+    converted = convertBaseValueToUnits(converted.value, type.units, type.divisor, converted.unit, preferredUnit);
   }
 
-  if (type.space && converted.unit.length > 0) {
-    converted.unit = ` ${converted.unit}`;
-  }
+  const formattedValue = formatValue(converted.value);
 
   return {
-    string: converted.value + converted.unit,
-    value: converted.value,
+    string: type.space ? `${formattedValue} ${converted.unit}`: formattedValue + converted.unit,
     unit: converted.unit,
+    value: converted.value,
   };
 };
 
-export const humanizeMem = v => humanize(v, 'binaryBytes', true).string;
-export const humanizeNumber = v => humanize(v, 'numeric', true).string;
+const formatPercentage = (value, options) => {
+  const {locales, ...rest} = _.defaults(
+    { style: 'percent' }, // Don't allow perent style to be overridden.
+    options,
+    {
+      maximumFractionDigits: 1,
+    }
+  );
+  return Intl.NumberFormat(locales, rest).format(value);
+};
+
+export const humanizeBinaryBytesWithoutB = (v, initialUnit, preferredUnit) => humanize(v, 'binaryBytesWithoutB', true, initialUnit, preferredUnit);
+export const humanizeBinaryBytes = (v, initialUnit, preferredUnit) => humanize(v, 'binaryBytes', true, initialUnit, preferredUnit);
+export const humanizeDecimalBytes = (v, initialUnit, preferredUnit) => humanize(v, 'decimalBytes', true, initialUnit, preferredUnit);
+export const humanizeDecimalBytesPerSec = (v, initialUnit, preferredUnit) => humanize(v, 'decimalBytesPerSec', true, initialUnit, preferredUnit);
+export const humanizeNumber = (v, initialUnit, preferredUnit) => humanize(v, 'numeric', true, initialUnit, preferredUnit);
+export const humanizeNumberSI = (v, initialUnit, preferredUnit) => humanize(v, 'SI', true, initialUnit, preferredUnit);
+export const humanizeSeconds = (v, initialUnit, preferredUnit) => humanize(v, 'seconds', true, initialUnit, preferredUnit);
+export const humanizeCpuCores = v => {
+  const value = v < 1 ? round(v*1000) : v;
+  const unit = v < 1 ? 'm' : '';
+  return {
+    string: `${formatValue(value)}${unit}`,
+    unit,
+    value,
+  };
+};
+export const humanizePercentage = value => {
+  if (!isFinite(value)) {
+    value = 0;
+  }
+  return {
+    string: formatPercentage(value/100),
+    unit: '%',
+    value: round(value, 1),
+  };
+};
 
 units.dehumanize = (value, typeName) => {
   const type = getType(typeName);
-
   return convertValueWithUnitsToBaseValue(value, type.units, type.divisor);
 };
 
